(() => {
  'use strict';

  // レコード追加画面／編集画面表示、レコード一覧画面のインライン編集開始
  // レコード保存のイベントは3種類あることに注意
  const eventsSubmit = [
    'app.record.create.submit',
    'app.record.edit.submit',
    'app.record.index.edit.submit',
  ];

  kintone.events.on(eventsSubmit, async (event) => {
    const record = event.record;

    // 売上集計用のオブジェクトを初期化
    const reportTable = {};

    // 「開始日付」と「終了日付」の間を検索条件とする
    const queryCondition =
      '日付 >= "' +
      record.開始日付.value +
      '" and 日付 <= "' +
      record.終了日付.value +
      '"';
    const params = {
      // 「日報」アプリのアプリID
      app: 52,
      query: queryCondition,
    };

    // 「日報」アプリを検索する
    try {
      const resp = await kintone.api(kintone.api.url('/k/v1/records', true), 'GET', params);

      // 成功時
      // 「日報」アプリの「売上明細」テーブルオブジェクトを取得する
      for (let i = 0; i < resp.records.length; i++) {
        // 「日報」アプリのテーブル内の1行を取得する
        const nippoTable = resp.records[i].売上明細.value;
        for (let j = 0; j < nippoTable.length; j++) {
          if (!reportTable[nippoTable[j].value.商品名.value]) {
            // 売上集計用のオブジェクトがundefinedの場合は追加する
            reportTable[nippoTable[j].value.商品名.value] = Number(
              nippoTable[j].value.売上金額.value
            );
          } else {
            // 売上集計用のオブジェクトの商品名と同じものがあればその売上金額に加算する
            reportTable[nippoTable[j].value.商品名.value] =
              Number(reportTable[nippoTable[j].value.商品名.value]) +
              Number(nippoTable[j].value.売上金額.value);
          }
        }
      }

      const tableRecords = [];
      for (const syohinName in reportTable) {
        if (reportTable.hasOwnProperty(syohinName)) {
          tableRecords.push({
            value: {
              商品名: {
                value: syohinName,
                type: 'SINGLE_LINE_TEXT',
              },
              売上金額: {
                value: reportTable[syohinName],
                type: 'NUMBER',
              },
            },
          });
        }
      }
      // 「_売上レポート」アプリの「売上明細」テーブルに上書き
      record.売上明細.value = tableRecords;
      return event;
    } catch (error) {
      // error:エラーの場合はメッセージを表示する
      let errmsg =
        '「日報」アプリのレコード取得時にエラーが発生しました。';
      // レスポンスにエラーメッセージが含まれる場合はメッセージを表示する
      if (error.message !== undefined) {
        errmsg += '\n' + error.message;
      }
      alert(errmsg);
      return event;
    }
  });
})();
