(() => {
  'use strict';

  // =============================================
  // 表示後イベント
  // 単一レコード取得（レコード番号が1のものを取得）
  // =============================================
  kintone.events.on('app.record.index.show', async (event) => {
    // 実行中のアプリIDを取得
    const appId = kintone.app.getId();
    // 取得条件:実行中のアプリのレコード番号1
    const params = {
      app: appId,
      id: 1,
    };
    // レコードを取得してJSON形式で表示
    try {
      const resp = await kintone.api(
        // APIのURL
        kintone.api.url('/k/v1/record', true),
        // GETメソッド
        'GET',
        // 取得条件のパラメータ
        params);
      // success:レスポンスをJSON形式で表示する
      console.log('===== 単一レコード取得 ================= >>> ');
      console.log(JSON.stringify(resp.record));
      return event;
    } catch (error) {
      // error:エラーの場合はメッセージを表示する
      let errmsg = 'レコード取得時にエラーが発生しました。';
      // レスポンスにエラーメッセージが含まれる場合はメッセージを表示する
      if (error.message !== undefined) {
        errmsg += '\n' + error.message;
      }
      alert(errmsg);
      return event;
    }
  });

  // =============================================
  // 表示後イベント
  // 複数レコード取得
  // =============================================
  kintone.events.on('app.record.index.show', async (event) => {
    // アプリID
    const appId = kintone.app.getId();
    // 抽出条件、並び順
    const queryCondition = kintone.app.getQueryCondition();
    // パラメータ配列
    const params = {
      app: appId,
      fields: ['会社名', '部署名', '担当者名'],
      query: queryCondition,
    };
    try {
      const resp = await kintone.api(kintone.api.url('/k/v1/records', true), 'GET', params);
      // 成功時
      console.log('===== 複数レコード取得 ================= >>> ');
      console.log(JSON.stringify(resp.records));
    } catch (error) {
      // error:エラーの場合はメッセージを表示する
      let errmsg = 'レコード取得時にエラーが発生しました。';
      // レスポンスにエラーメッセージが含まれる場合はメッセージを表示する
      if (error.message !== undefined) {
        errmsg += '\n' + error.message;
      }
      alert(errmsg);
    }
  });
})();
