(() => {
  'use strict';

  const eventName = ['app.record.create.show', 'app.record.edit.show',];

  // 編集画面
  kintone.events.on(eventName, (event) => {
    // 設置するためのボタンの定義
    const searchZipButton = document.createElement('button');
    searchZipButton.innerText = '郵便番号変換';
    searchZipButton.onclick = async () => {
      const record = kintone.app.record.get().record;
      // ハイフン有無に対応
      const postcode = record['郵便番号'].value;
      // 前半３桁
      let post3 = '';
      // 後半４桁
      let post4 = '';
      if (postcode.length === 7) {
        post3 = postcode.slice(0, 3);
        post4 = postcode.slice(3, 7);
      } else if (postcode.length === 8) {
        post3 = postcode.slice(0, 3);
        post4 = postcode.slice(4, 8);
      }

      const url = 
      `https://madefor.github.io/postal-code-api/api/v1/${post3}/${post4}.json`;

      try {
        // 外部API呼出
        const resp = await kintone.proxy(url, 'GET', {}, {});
        // 成功時
        if (resp[1] === 200) {
          // ステータス正常時
          // JSON文字列をJSONオブジェクトに変換
          const obj = JSON.parse(resp[0]);
          // 現在開いてるレコードデータをJSON形式で取得
          record['都道府県'].value = obj.data[0].ja.prefecture;
          record['市区町村'].value = obj.data[0].ja.address1;
          record['町域名'].value = obj.data[0].ja.address2;
          // 現在開いてるレコードに値をセット
          kintone.app.record.set({ record: record });
        } else {
          // ステータス異常時
          alert(resp[1] + ':住所が見つかりませんでした。');
        }
      } catch (error) {
        // 失敗時
        alert('住所の検索に失敗しました。');
      }
    };

    // スペースフィールドにボタン設置
    kintone.app.record.getSpaceElement('space').appendChild(searchZipButton);
  });
})();
