(() => {
  'use strict';
  kintone.events.on('app.record.detail.show', (event) => {
    // 「商品マスタ」アプリのアプリID
    const productApp = 128;
    // 「受注」アプリのアプリID
    const orderApp = 127;
    // 受注ボタンの定義
    const createOrderButton = document.createElement('button');
    createOrderButton.innerText = '受注する';
    createOrderButton.onclick = async () => {
      const record = kintone.app.record.get().record;
      // 該当の商品を「商品マスタ」アプリから検索する
      const resp = await kintone.api(kintone.api.url('/k/v1/record', true), 'GET', {
        app: productApp,
        id: record.商品ID.value,
      });
      const itemRecord = resp.record;

      // 在庫数が見積もり数量より少ない場合は受注できないようにする
      if (Number(itemRecord.在庫数.value) < Number(record.数量.value)) {
        alert('商品マスタの在庫が足りません');
        return;
      }

      try {
        // 在庫がある場合は「商品マスタ」アプリで在庫引当を行いつつ、
        // 「受注」アプリに「見積もり」アプリの内容を転記する
        await kintone.api(kintone.api.url('/k/v1/bulkRequest', true), 'POST', {
          requests: [
            // 「商品マスタ」アプリで在庫引当
            {
              method: 'PUT',
              api: '/k/v1/record.json',
              payload: {
                app: productApp,
                id: record.商品ID.value,
                record: {
                  在庫数: {
                    value: Number(itemRecord.在庫数.value) - Number(record.数量.value)
                  }
                }
              }
            },
            // 「受注」アプリに見積もりの内容を登録
            {
              method: 'POST',
              api: '/k/v1/record.json',
              payload: {
                app: orderApp,
                record: {
                  商品ID: { value: record.商品ID.value },
                  数量: { value: record.数量.value },
                }
              }
            },
          ]
        });
        alert('受注を作成しました');

      } catch (error) {
        alert('在庫引当、受注が失敗しました');
      }

    };

    // 詳細画面の上部にボタン設置
    kintone.app.record.getHeaderMenuSpaceElement().appendChild(createOrderButton);
  });

})();